@@ -7,7 +7,7 @@
 * re-register components.
 *
 */
-#define NS_BUILD_ID 2005032321
+#define NS_BUILD_ID 2004061813
 
 /* GRE_BUILD_ID - GRE build version identifier
  *
@@ -17,7 +17,7 @@
  * GRE_BUILD_ID will just contain <milestone>. 
  *
  */
-#define GRE_BUILD_ID "1.4.4f_2005032321"
+#define GRE_BUILD_ID "1.7_2004061813"
 
 #endif /* _NSBUILDID_H_ */
 
